@@ -8,6 +8,8 @@ File Classes
 ^^^^^^^^^^^^
 
 .. autosummary::
+   :toctree: generated
+
    File
    LineFile
    BlockFile
@@ -15,22 +17,23 @@ File Classes
 
 ----
 """
+import copy
 import os
 import shutil
 import time
-import copy
 
 from ogs5py.tools.tools import (
-    format_content_line,
+    find_key_in_list,
     format_content,
-    search_mkey,
-    uncomment,
+    format_content_line,
     get_key,
     is_key,
     is_mkey,
     is_skey,
-    find_key_in_list,
+    search_mkey,
+    uncomment,
 )
+
 try:
     from ogs5py._version import __version__ as version
 except ImportError:  # pragma: nocover
@@ -51,7 +54,7 @@ BOT_COM = (
 )
 
 
-class File(object):
+class File:
     """
     File class with minimal functionality.
 
@@ -272,7 +275,7 @@ class LineFile(File):
         task_root=None,
         task_id="model",
     ):
-        super(LineFile, self).__init__(task_root, task_id, file_ext)
+        super().__init__(task_root, task_id, file_ext)
         self.lines = [] if lines is None else lines
         self.name = name
 
@@ -394,7 +397,7 @@ class BlockFile(File):
     """:class:`dict`: Standard Block OGS-BlockFile"""
 
     def __init__(self, task_root=None, task_id="model", file_ext=".std"):
-        super(BlockFile, self).__init__(task_root, task_id, file_ext)
+        super().__init__(task_root, task_id, file_ext)
 
         # list of main keywords indicated by "#"
         self.mainkw = []
@@ -1037,7 +1040,7 @@ class BlockFile(File):
         update : bool, optional
             state if the content should be updated before saving. Default: True
         """
-        from ogs5py import SUB_IND, CON_IND
+        from ogs5py import CON_IND, SUB_IND
 
         if "update" in kwargs:
             update = bool(kwargs["update"])
@@ -1086,7 +1089,7 @@ class BlockFile(File):
                                 # sep="\t", end="\n", file=fout)
                                 sep=" ",
                                 end=lend,
-                                file=fout
+                                file=fout,
                             )
                         elif CON_IND:
                             print(
@@ -1094,7 +1097,7 @@ class BlockFile(File):
                                 *con,
                                 sep=" ",
                                 end=lend,
-                                file=fout
+                                file=fout,
                             )
                         else:
                             print(*con, sep=" ", end=lend, file=fout)
@@ -1107,7 +1110,7 @@ class BlockFile(File):
 
     def __repr__(self):
         """Representation."""
-        from ogs5py import SUB_IND, CON_IND
+        from ogs5py import CON_IND, SUB_IND
 
         out = ""
         for i, mkey in enumerate(self.mainkw):
@@ -1127,7 +1130,7 @@ class BlockFile(File):
         return out
 
 
-class MultiFile(object):
+class MultiFile:
     """
     Class holding mulitple files of the same type.
 
